@@ -77,7 +77,7 @@ class NullHandler(logging.Handler):
 logger = logging.getLogger('pandaemonium')
 logger.addHandler(NullHandler())
 
-version = 0, 5, 1
+version = 0, 5, 3
 
 STDIN = 0
 STDOUT = 1
@@ -143,7 +143,7 @@ class Daemon(object):
                                         # None means True unless started by init
                                         # or superserver
             working_directory='/',      # directory to change to
-            umask=0,                    # don't mask anything for file creation
+            umask=0o027,                # allow group reads, and world nothing
             prevent_core=True,          # don't write core files
             process_ids=None,           # uid, gid to switch to (None means ask
                                         # the os who is really running things
@@ -195,6 +195,10 @@ class Daemon(object):
             self._stage_completed = 10
         except Parent:
             self.i_am = 'parent'
+            if self.output:
+                print(self.output)
+            if self.error:
+                print(self.error)
             os._exit(os.EX_OK)
 
     def __detach(self):
@@ -364,6 +368,8 @@ class Daemon(object):
     def stage4(self):
         """
         Change umask.
+
+        Default setting allows group read/execute, and world nothing.
         """
         self.logger.info('  setting umask: %s' % self.umask)
         os.umask(self.umask)
